@@ -163,6 +163,8 @@ class Scene:
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "cube"
@@ -187,6 +189,8 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "sphere"
@@ -216,6 +220,8 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "line"
@@ -243,6 +249,8 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "lines"
@@ -253,12 +261,14 @@ class Scene:
 
     def add_points(self, name : str,
                    points : np.ndarray,
+                   point_size : float = 1.0,
                    **kwargs):
         """
         Add a point cloud (in browser, points are always size 1 right now)
 
         :param name: an identifier for this object
         :param points: (N, 3) float, list of points
+        :param point_size: float, point size
         :param color: (3,) color, default is orange (common param)
         :param vert_color: (N, 3) vertex color, optional (overrides color) (common param)
         :param translation: (3,), model translation (common param)
@@ -267,10 +277,14 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "points"
         self.fields[_f(name, "points")] = np.array(points).astype(np.float32)
+        if point_size != 1.0:
+            self.fields[_f(name, "point_size")] = np.float32(point_size)
         self._update_bb(points, **kwargs)
 
     def add_mesh(self, name : str,
@@ -295,6 +309,8 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         """
         self._add_common(name, **kwargs)
         self.fields[name] = "mesh"
@@ -343,6 +359,8 @@ class Scene:
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
         :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
         :param update_view: bool, if true then updates the camera position, scene origin etc
                             using these cameras
         """
@@ -409,6 +427,8 @@ class Scene:
         :param path: the path to the mesh file
         :param name_suffix: object name will be basename(path) + name_suffix
         :param center: if true, centers object to mean
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
 
         Rest of keyword arguments passed to add_mesh
         """
@@ -429,6 +449,8 @@ class Scene:
 
         :param name: identifier, default "axes"
         :param length: float, length of axes
+        :param time: int, time at which the mesh should be displayed; 0=always display (default)
+                    (common param)
 
         Rest of keyword arguments passed to add_lines
         """
